@@ -71,7 +71,13 @@
 #endif
 
 #include <net/if.h>  // IFF_UP
-#include <ifaddrs.h> // getifaddrs()
+
+#ifdef HAVE_IFADDRS_H
+#include <ifaddrs.h>
+#else
+#include "ifaddr/ifaddrs.h"
+#endif
+
 
 #if defined(__linux__) && defined(NEED_TIMEVAL)
 struct timeval 
@@ -243,7 +249,6 @@ rfbProcessNewConnection(rfbScreenInfoPtr rfbScreen, int insock)
 {
     const int one = 1;
     int sock = -1;
-    int i;
     
     if((sock = accept(insock, NULL, NULL)) < 0) {
       rfbLogPerror("rfbCheckFds: accept");
