@@ -35,6 +35,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <netdb.h>
+#include <sys/socket.h>
 #include <net/if.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
@@ -81,22 +82,22 @@ enum
 
 static gboolean
 vino_dbus_listener_get_external_port (VinoDBusListener *listener,
-                                      gdouble *ret,
-                                      GError **error);
+                                      gint             *ret,
+                                      GError           **error);
 
 static gboolean
 vino_dbus_listener_get_internal_data (VinoDBusListener *listener,
-                                      char ** hostname,
-                                      char ** avahi_hostname,
-                                      gdouble * port,
-                                      GError **error);
+                                      char             **hostname,
+                                      char             **avahi_hostname,
+                                      gint             *port,
+                                      GError           **error);
 
 static gboolean
 vino_dbus_listener_share_with_tube (VinoDBusListener *listener,
-                                    const gchar * connection_path,
-                                    const gchar * tube_path,
-                                    GHashTable * properties,
-                                    GError **error);
+                                    const gchar      *connection_path,
+                                    const gchar      *tube_path,
+                                    GHashTable       *properties,
+                                    GError           **error);
 
 #include "dbus-interface-glue.h"
 
@@ -297,8 +298,8 @@ vino_dbus_listener_new (VinoServer *server)
 
 static gboolean
 vino_dbus_listener_get_external_port (VinoDBusListener *listener,
-                                      gdouble *ret,
-                                      GError **error)
+                                      gint             *ret,
+                                      GError           **error)
 {
   *ret = vino_server_get_external_port (listener->priv->server);
 
@@ -308,19 +309,18 @@ vino_dbus_listener_get_external_port (VinoDBusListener *listener,
 
 static gboolean
 vino_dbus_listener_get_internal_data (VinoDBusListener *listener,
-                                      char ** hostname,
-                                      char ** avahi_hostname,
-                                      gdouble * port,
-                                      GError **error)
+                                      char             **hostname,
+                                      char             **avahi_hostname,
+                                      gint             *port,
+                                      GError           **error)
 {
 #ifdef VINO_ENABLE_HTTP_SERVER
-  *port = (gdouble)vino_get_http_server_port (listener->priv->server);
+  *port = vino_get_http_server_port (listener->priv->server);
 #else
-  *port = (gdouble)vino_server_get_port (listener->priv->server);
+  *port = vino_server_get_port (listener->priv->server);
 #endif
 
   *hostname = get_local_hostname (listener);
-
   *avahi_hostname = g_strdup (vino_mdns_get_hostname ());
 
   return TRUE;
@@ -377,9 +377,10 @@ vino_dbus_listener_set_server (VinoDBusListener *listener,
 
   dprintf (DBUS, "Object registered at path '%s'\n", obj_path);
 
-  g_signal_connect (server, "notify::alternative-port",
-      G_CALLBACK (vino_dbus_listener_info_changed),
-      listener);
+  g_signal_connect (server,
+		    "notify::alternative-port",
+		    G_CALLBACK (vino_dbus_listener_info_changed),
+		    listener);
 
   g_free (obj_path);
 }
@@ -392,30 +393,30 @@ vino_dbus_listener_get_server (VinoDBusListener *listener)
   return listener->priv->server;
 }
 
-static DBusGConnection * vino_dbus_connection = NULL;
+static DBusGConnection *vino_dbus_connection = NULL;
 static gboolean        vino_dbus_failed_to_connect = FALSE;
 
 DBusGConnection *
 vino_dbus_get_connection (void)
 {
-  DBusConnection * dbus_conn;
   if (vino_dbus_connection == NULL && !vino_dbus_failed_to_connect)
     {
-      GError * error = NULL;
+      GError *error = NULL;
 
       if ((vino_dbus_connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error)))
-        {
-          dprintf (DBUS, "Successfully connected to the message bus\n");
-          dbus_conn = dbus_g_connection_get_connection (vino_dbus_connection);
-          dbus_connection_set_exit_on_disconnect (dbus_conn, FALSE);
-        }
+	{
+	  DBusConnection * dbus_conn;
+
+	  dprintf (DBUS, "Successfully connected to the message bus\n");
+	  dbus_conn = dbus_g_connection_get_connection (vino_dbus_connection);
+	  dbus_connection_set_exit_on_disconnect (dbus_conn, FALSE);
+	}
       else
-        {
-          vino_dbus_failed_to_connect = TRUE;
-          g_printerr ("Failed to open connection to bus: %s\n",
-              error->message);
-          g_error_free (error);
-        }
+	{
+	  vino_dbus_failed_to_connect = TRUE;
+	  dprintf (DBUS, "Failed to open connection to bus: %s\n", error->message);
+	  g_error_free (error);
+	}
     }
 
   return vino_dbus_connection;
@@ -426,29 +427,33 @@ vino_dbus_request_name (void)
 {
 
   DBusGConnection *connection;
-  GError *error = NULL;
-  DBusGProxy     *bus_proxy;
-  int request_name_result;
+  DBusGProxy      *bus_proxy;
+  guint           request_name_result;
+  GError          *error = NULL;
 
   if (!(connection = vino_dbus_get_connection ()))
     return FALSE;
 
   dbus_g_object_type_install_info (VINO_TYPE_DBUS_LISTENER,
-      &dbus_glib_vino_dbus_listener_object_info);
+				   &dbus_glib_vino_dbus_listener_object_info);
 
   bus_proxy = dbus_g_proxy_new_for_name (connection,
       "org.freedesktop.DBus",
       "/org/freedesktop/DBus",
       "org.freedesktop.DBus");
 
-  if (!dbus_g_proxy_call(bus_proxy, "RequestName", &error, 
-      G_TYPE_STRING, VINO_DBUS_BUS_NAME, G_TYPE_UINT, 0, G_TYPE_INVALID,
-      G_TYPE_UINT, &request_name_result, G_TYPE_INVALID))
+  if (!dbus_g_proxy_call (bus_proxy,
+			  "RequestName",
+			  &error,
+			  G_TYPE_STRING, VINO_DBUS_BUS_NAME,
+			  G_TYPE_UINT, DBUS_NAME_FLAG_DO_NOT_QUEUE,
+			  G_TYPE_INVALID,
+			  G_TYPE_UINT, &request_name_result,
+			  G_TYPE_INVALID))
     {
-      g_debug ("Failed to request name: %s",
-                error ? error->message : "No error given");
+      dprintf (DBUS, "Failed to request DBUS name: %s", error ? error->message : "No error given");
       g_clear_error (&error);
-      return FALSE ;
+      return FALSE;
     }
 
   if (request_name_result == DBUS_REQUEST_NAME_REPLY_EXISTS)
