@@ -117,7 +117,7 @@ vino_status_icon_update_state (VinoStatusIcon *icon)
   else
     visible = visible && (icon->priv->visibility == VINO_STATUS_ICON_VISIBILITY_ALWAYS);
 
-  gtk_status_icon_set_tooltip (GTK_STATUS_ICON (icon), tooltip);
+  gtk_status_icon_set_tooltip_text (GTK_STATUS_ICON (icon), tooltip);
   gtk_status_icon_set_visible (GTK_STATUS_ICON (icon), visible);
 
   g_free (tooltip);
@@ -335,15 +335,19 @@ vino_status_icon_disconnect_confirm (VinoStatusIconNotify *a)
   if (client != NULL)
     {
       /* Translators: %s is a hostname */
-      primary_msg   = g_strdup_printf (_("Are you sure you want to disconnect '%s'?"),
-                                       vino_client_get_hostname (client));
-      secondary_msg = g_strdup_printf (_("The remote user from '%s' will be disconnected. Are you sure?"),
-                                       vino_client_get_hostname (client));
+      primary_msg   = g_strdup_printf
+          (_("Are you sure you want to disconnect '%s'?"),
+          vino_client_get_hostname (client));
+      secondary_msg = g_strdup_printf
+          (_("The remote user from '%s' will be disconnected. Are you sure?"),
+          vino_client_get_hostname (client));
     }
   else
     {
-      primary_msg   = g_strdup (_("Are you sure you want to disconnect all clients?"));
-      secondary_msg = g_strdup (_("All remote users will be disconnected. Are you sure?"));
+      primary_msg   = g_strdup
+          (_("Are you sure you want to disconnect all clients?"));
+      secondary_msg = g_strdup
+          (_("All remote users will be disconnected. Are you sure?"));
     }
 
   icon->priv->disconnect_dialog = gtk_message_dialog_new (NULL,
@@ -420,7 +424,8 @@ vino_status_icon_popup_menu (GtkStatusIcon *status_icon,
       a->client = client;
 
       /* Translators: %s is a hostname */
-      str = g_strdup_printf (_("Disconnect %s"), vino_client_get_hostname (client));
+      str = g_strdup_printf (_("Disconnect %s"),
+          vino_client_get_hostname (client));
 
       item  = gtk_image_menu_item_new_with_label (str);
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
@@ -480,13 +485,17 @@ vino_status_icon_add_client (VinoStatusIcon *icon,
 
   vino_status_icon_update_state (icon);
 
-  VinoStatusIconNotify *a;
-  a = g_new (VinoStatusIconNotify, 1);
-  a->icon   = icon;
-  a->client = client;
-  g_timeout_add (1000, 
-                 vino_status_icon_show_new_client_notification,
-                 (gpointer) a);
+  if (gtk_status_icon_get_visible (GTK_STATUS_ICON (icon)))
+    {
+      VinoStatusIconNotify *a;
+
+      a = g_new (VinoStatusIconNotify, 1);
+      a->icon   = icon;
+      a->client = client;
+      g_timeout_add_seconds (1, 
+                             vino_status_icon_show_new_client_notification,
+                             (gpointer) a);
+    }
 }
 
 gboolean
@@ -597,15 +606,19 @@ vino_status_icon_show_new_client_notification (gpointer user_data)
 
   if (vino_server_get_view_only (icon->priv->server))
     {
+      /* Translators: %s is a hostname */
       summary = _("Another user is viewing your desktop");
-      body = g_strdup_printf (_("A user on the computer '%s' is remotely viewing your desktop."),
-                              vino_client_get_hostname (client));
+      body = g_strdup_printf
+          (_("A user on the computer '%s' is remotely viewing your desktop."),
+          vino_client_get_hostname (client));
     }
   else
     {
+      /* Translators: %s is a hostname */
       summary = _("Another user is controlling your desktop");
-      body = g_strdup_printf (_("A user on the computer '%s' is remotely controlling your desktop."),
-                              vino_client_get_hostname (client));
+      body = g_strdup_printf
+          (_("A user on the computer '%s' is remotely controlling "
+          "your desktop."), vino_client_get_hostname (client));
     }
 
   icon->priv->new_client_notification =
